@@ -22,7 +22,7 @@ package MongoDB;
 # ABSTRACT: Official MongoDB Driver for Perl
 
 use version;
-our $VERSION = 'v1.0.1';
+our $VERSION = 'v1.0.2';
 
 # regexp_pattern was unavailable before 5.10, had to be exported to load the
 # function implementation on 5.10, and was automatically available in 5.10.1
@@ -106,7 +106,7 @@ MongoDB - Official MongoDB Driver for Perl
 
 =head1 VERSION
 
-version v1.0.1
+version v1.0.2
 
 =head1 SYNOPSIS
 
@@ -285,7 +285,7 @@ Florian Ragwitz <rafl@debian.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Andrew Page Andrey Khozov Ashley Willis Ask Bjørn Hansen Bernard Gorman Brendan W. McAdams Casey Rojas Christian Sturm Walde Colin Cyr Danny Raetzsch David Morrison Nadle Steinbrunner Storch D. Ilmari Mannsåker Eric Daniels Gerard Goossen Glenn Fowler Graham Barr Jason Carey Toffaletti Johann Rolschewski Joseph Harnish Joshua Juran J. Stewart Kamil Slowikowski Ken Williams Matthew Shopsin Michael Langner Rotmanov Mike Dirolf Nickola Trupcheff Nuno Carvalho Orlando Vazquez Othello Maurer Pan Fan Robin Lee Roman Yerin Ronald J Kimball Ryan Chipman Stephen Oberholtzer Steve Sanbeg Stuart Watt Uwe Voelker Whitney Jackson Xtreak Zhihong Zhang
+=for stopwords Andrew Page Andrey Khozov Ashley Willis Ask Bjørn Hansen Bernard Gorman Brendan W. McAdams Casey Rojas Christian Sturm Walde Colin Cyr Danny Raetzsch David Golden Morrison Nadle Steinbrunner Storch D. Ilmari Mannsåker Eric Daniels Gerard Goossen Glenn Fowler Graham Barr Jason Carey Toffaletti Johann Rolschewski Joseph Harnish Joshua Juran J. Stewart Kamil Slowikowski Ken Williams Matthew Shopsin Michael Langner Rotmanov Mike Dirolf Nickola Trupcheff Nuno Carvalho Orlando Vazquez Othello Maurer Pan Fan rahuldhodapkar Robin Lee Roman Yerin Ronald J Kimball Ryan Chipman Stephen Oberholtzer Steve Sanbeg Stuart Watt Uwe Voelker Whitney Jackson Xtreak Zhihong Zhang
 
 =over 4
 
@@ -339,6 +339,10 @@ Danny Raetzsch <danny@paperskymedia.com>
 
 =item *
 
+David Golden <xdg@xdg.me>
+
+=item *
+
 David Morrison <dmorrison@venda.com>
 
 =item *
@@ -443,6 +447,10 @@ Pan Fan <nightsailer@gmail.com>
 
 =item *
 
+rahuldhodapkar <rahul.m.dhodapkar@gmail.com>
+
+=item *
+
 Robin Lee <cheeselee@fedoraproject.org>
 
 =item *
