@@ -19,7 +19,7 @@ package MongoDB::MongoClient;
 # ABSTRACT: A connection to a MongoDB server or multi-server deployment
 
 use version;
-our $VERSION = 'v1.0.1';
+our $VERSION = 'v1.0.2';
 
 use Moo;
 use MongoDB;
@@ -88,6 +88,10 @@ $MongoDB::BSON::char = '$';
 #pod
 #pod Defaults to the connection string URI C<mongodb://localhost:27017>.
 #pod
+#pod For IPv6 support, you must have a recent version of L<IO::Socket::IP>
+#pod installed.  This module ships with the Perl core since v5.20.0 and is
+#pod available on CPAN for older Perls.
+#pod
 #pod =cut
 
 has host => (
@@ -790,8 +794,8 @@ sub _build_w {
 
 #pod =attr wtimeout
 #pod
-#pod The number of milliseconds an operation should wait for C<w> slaves to replicate
-#pod it.
+#pod The number of milliseconds an operation should wait for C<w> secondaries to
+#pod replicate it.
 #pod
 #pod Defaults to 1000 (1 second).
 #pod
@@ -822,9 +826,10 @@ sub _build_wtimeout {
 
 #pod =attr dt_type (DEPRECATED AND READ-ONLY)
 #pod
-#pod Sets the type of object which is returned for DateTime fields. The default is
-#pod L<DateTime>. Other acceptable values are L<DateTime::Tiny>, L<Time::Moment> and
-#pod C<undef>. The latter will give you the raw epoch value rather than an object.
+#pod Sets the type of object which is returned for DateTime fields. The default
+#pod is L<DateTime>. Other acceptable values are L<DateTime::Tiny>,
+#pod L<Time::Moment> and C<undef>. The latter will give you the raw epoch value
+#pod (possibly as a floating point value) rather than an object.
 #pod
 #pod This will be used to construct L</bson_codec> object if one is not provided.
 #pod
@@ -1508,7 +1513,7 @@ MongoDB::MongoClient - A connection to a MongoDB server or multi-server deployme
 
 =head1 VERSION
 
-version v1.0.1
+version v1.0.2
 
 =head1 SYNOPSIS
 
@@ -1579,6 +1584,10 @@ STRING URI> with a seed list of one or more servers plus connection options.
 
 Defaults to the connection string URI C<mongodb://localhost:27017>.
 
+For IPv6 support, you must have a recent version of L<IO::Socket::IP>
+installed.  This module ships with the Perl core since v5.20.0 and is
+available on CPAN for older Perls.
+
 =head2 auth_mechanism
 
 This attribute determines how the client authenticates with the server.
@@ -1958,8 +1967,8 @@ This may be set in a connection string with the C<w> option.
 
 =head2 wtimeout
 
-The number of milliseconds an operation should wait for C<w> slaves to replicate
-it.
+The number of milliseconds an operation should wait for C<w> secondaries to
+replicate it.
 
 Defaults to 1000 (1 second).
 
@@ -1969,9 +1978,10 @@ This may be set in a connection string with the C<wTimeoutMS> option.
 
 =head2 dt_type (DEPRECATED AND READ-ONLY)
 
-Sets the type of object which is returned for DateTime fields. The default is
-L<DateTime>. Other acceptable values are L<DateTime::Tiny>, L<Time::Moment> and
-C<undef>. The latter will give you the raw epoch value rather than an object.
+Sets the type of object which is returned for DateTime fields. The default
+is L<DateTime>. Other acceptable values are L<DateTime::Tiny>,
+L<Time::Moment> and C<undef>. The latter will give you the raw epoch value
+(possibly as a floating point value) rather than an object.
 
 This will be used to construct L</bson_codec> object if one is not provided.
 
