@@ -19,12 +19,15 @@ package MongoDB::OID;
 # ABSTRACT: A Mongo Object ID
 
 use version;
-our $VERSION = 'v1.0.1';
+our $VERSION = 'v1.0.2';
 
 use MongoDB::BSON;
 use Moo;
 use MongoDB;
 use MongoDB::_Constants;
+use MongoDB::_Types qw(
+    OID
+);
 use Types::Standard qw(
     Str
 );
@@ -45,7 +48,8 @@ has value => (
     is      => 'ro',
     required => 1,
     builder => '_build_value',
-    isa => Str,
+    isa => OID,
+    coerce => OID->coercion,
 );
 
 # XXX need to set up typedef with str length
@@ -147,7 +151,7 @@ MongoDB::OID - A Mongo Object ID
 
 =head1 VERSION
 
-version v1.0.1
+version v1.0.2
 
 =head1 SYNOPSIS
 
