@@ -19,7 +19,7 @@ package MongoDB::QueryResult;
 # ABSTRACT: An iterator for Mongo query results
 
 use version;
-our $VERSION = 'v1.0.1';
+our $VERSION = 'v1.0.2';
 
 use Moo;
 use MongoDB::Error;
@@ -137,7 +137,12 @@ sub _add_docs {
     push @{$self->{_docs}}, @_;
 }
 sub _next_doc { shift @{$_[0]{_docs}} }
-sub _clear_doc { @{$_[0]{_docs}} = () }
+sub _drain_docs {
+    my @docs = @{$_[0]{_docs}};
+    $_[0]{_cursor_at} += scalar @docs;
+    @{$_[0]{_docs}} = ();
+    return @docs;
+}
 
 # for backwards compatibility
 sub started_iterating() { 1 }
@@ -228,11 +233,7 @@ sub _get_more {
 sub all {
     my ($self) = @_;
     my @ret;
-
-    while ( my $entry = $self->next ) {
-        push @ret, $entry;
-    }
-
+    push @ret, $self->_drain_docs while $self->has_next;
     return @ret;
 }
 
@@ -334,7 +335,7 @@ MongoDB::QueryResult - An iterator for Mongo query results
 
 =head1 VERSION
 
-version v1.0.1
+version v1.0.2
 
 =head1 SYNOPSIS
 
