@@ -19,7 +19,7 @@ package MongoDB::QueryResult::Filtered;
 # ABSTRACT: An iterator for Mongo query results with client-side filtering
 
 use version;
-our $VERSION = 'v1.0.1';
+our $VERSION = 'v1.0.2';
 
 use Moo;
 use Types::Standard qw(
@@ -30,6 +30,8 @@ extends 'MongoDB::QueryResult';
 
 use namespace::clean;
 
+# N.B.: _post_filter may also munge documents in addition to filtering;
+# it *must* be run on all documents
 has _post_filter => (
     is       => 'ro',
     isa      => CodeRef,
@@ -59,6 +61,14 @@ sub has_next {
     return 0;
 }
 
+sub all {
+    my ($self) = @_;
+    my @ret;
+    push @ret, grep { $self->_post_filter->($_) } $self->_drain_docs
+        while $self->has_next;
+    return @ret;
+}
+
 1;
 
 __END__
@@ -73,7 +83,7 @@ MongoDB::QueryResult::Filtered - An iterator for Mongo query results with client
 
 =head1 VERSION
 
-version v1.0.1
+version v1.0.2
 
 =for Pod::Coverage has_next
 
